@@ -132,7 +132,7 @@ func snapshotWaitCommand() *core.Command {
 				Required:   true,
 				Positional: true,
 			},
-			core.ZoneArgSpec(),
+			core.ZoneArgSpec((*instance.API)(nil).Zones()...),
 			core.WaitTimeoutArgSpec(snapshotActionTimeout),
 		},
 		Examples: []*core.Example{
